@@ -25,6 +25,9 @@
 #define __ABORT_H_
 
 #include <sys/cdefs.h>
+#include <_bounds.h>
+
+_LIBC_SINGLE_BY_DEFAULT()
 
 __BEGIN_DECLS
 void	 abort(void) __cold __dead2;
