@@ -9,6 +9,13 @@
 
 #include <corecrt.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+unsigned __int64* __local_stdio_printf_options(void);
+unsigned __int64* __local_stdio_scanf_options(void);
+
 #define _CRT_INTERNAL_PRINTF_LEGACY_VSPRINTF_NULL_TERMINATION  0x0001ULL
 #define _CRT_INTERNAL_PRINTF_STANDARD_SNPRINTF_BEHAVIOR        0x0002ULL
 #define _CRT_INTERNAL_PRINTF_LEGACY_WIDE_SPECIFIERS            0x0004ULL
@@ -21,11 +28,14 @@
 #define _CRT_INTERNAL_SCANF_LEGACY_MSVCRT_COMPATIBILITY  0x0004ULL
 
 #ifndef _CRT_INTERNAL_LOCAL_PRINTF_OPTIONS
-#define _CRT_INTERNAL_LOCAL_PRINTF_OPTIONS  (_CRT_INTERNAL_PRINTF_LEGACY_WIDE_SPECIFIERS | _CRT_INTERNAL_PRINTF_STANDARD_ROUNDING)
+#define _CRT_INTERNAL_LOCAL_PRINTF_OPTIONS  (*__local_stdio_printf_options())
 #endif
 
 #ifndef _CRT_INTERNAL_LOCAL_SCANF_OPTIONS
-#define _CRT_INTERNAL_LOCAL_SCANF_OPTIONS   _CRT_INTERNAL_SCANF_LEGACY_WIDE_SPECIFIERS
+#define _CRT_INTERNAL_LOCAL_SCANF_OPTIONS   (*__local_stdio_scanf_options())
 #endif
 
+#ifdef __cplusplus
+}
+#endif
 #endif /* _STDIO_CONFIG_DEFINED */
